@@ -13,7 +13,7 @@ def linkcode_helper(domain, info,
     if domain != 'py' or not info['module']:
         return None
     # try to find the file and line number, based on code from numpy:
-    # https://github.com/numpy/numpy/blob/master/doc/source/conf.py#L286
+    # https://github.com/numpy/numpy/blob/master/doc/source/conf.py#L405
     github_url = github_url.removesuffix('/')
     obj = sys.modules[info['module']]
     for part in info['fullname'].split('.'):
@@ -21,6 +21,16 @@ def linkcode_helper(domain, info,
             obj = getattr(obj, part)
         except Exception:
             return None
+
+    # strip decorators, which would resolve to the source of the decorator
+    # possibly an upstream bug in getsourcefile, bpo-1764286
+    try:
+        unwrap = inspect.unwrap
+    except AttributeError:
+        pass
+    else:
+        obj = unwrap(obj)
+
     try:
         fn = inspect.getsourcefile(obj)
     except Exception:
